pub struct AbsoluteTime { /* private fields */ }Expand description
An absolute time which are binded to the system’s clock
and never be zero except when timer is reset.
Implementations
AbsoluteTime::from(LocalTime::now()); AbsoluteTime::from(Duration::from_sec(1)); AbsoluteTime::from(10); AbsoluteTime::from((10, 46000)); AbsoluteTime::new_time(10, 46000);Implementations
Sourceimpl AbsoluteTime
impl AbsoluteTime
pub fn new_time(time_sec: i64, time_nsec: i64) -> Option<Self>
Sourcepub unsafe fn new_time_unchecked(time_sec: i64, time_nsec: i64) -> Self
pub unsafe fn new_time_unchecked(time_sec: i64, time_nsec: i64) -> Self
Creates new instance for absolute time accepting the user input.
Automatically corrects the time_nsec value if it is larger than
999_999_999ns.
Arguments
time_sec - i64 a seconds in absolute notation.
time_nsec - i64 nanoseconds of absolute seconds value. Should not be
larger than 999_999_999 which is defined by const Self::MAX_NS. In
case if it is larger, the nsec will be rounded and an extra secons
will be added.
Returns
An instance is returned. May panic on overflow.
Sourcepub fn seconds_cmp(&self, other: &Self) -> Ordering
pub fn seconds_cmp(&self, other: &Self) -> Ordering
Compares only full seconds without nanoseconds fraction (subnano).
pub fn add_sec(self, seconds: i64) -> Self
pub fn reset_nsec(self) -> Self